@@ -16,10 +16,6 @@
 #ifndef SW_MODULE_H_
 #define SW_MODULE_H_
 
-#include "swoole.h"
-#include "Server.h"
-#include "Client.h"
-
 #ifdef __cplusplus
 extern "C"
 {
@@ -30,12 +26,10 @@ typedef struct _swModule
     void *handle;
     char *file;
     char *name;
-    int (*beforeDispatch)(struct _swModule*, swServer *, swEventData *data);
-    int (*beforeReceive)(struct _swModule*, swServer *, swEventData *data);
-    int (*shutdown)(struct _swModule*);
 } swModule;
 
 swModule* swModule_load(char *so_file);
+void swModule_free(swModule* module);
 int swModule_register_global_function(const char *name, void* func);
 void* swModule_get_global_function(char *name, uint32_t length);
 
